Control logic
-------------

The file ``mockturtle/generators/control.hpp`` implements several functions to
generate control logic networks.

.. doxygenfunction:: mockturtle::constant_word
.. doxygenfunction:: mockturtle::zero_extend
.. doxygenfunction:: mockturtle::mux_inplace
.. doxygenfunction:: mockturtle::binary_decoder
.. doxygenfunction:: mockturtle::binary_mux
.. doxygenfunction:: mockturtle::binary_mux_klein_paterson
